aboutsummaryrefslogtreecommitdiff
path: root/src/node/chainstate.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/node/chainstate.h')
-rw-r--r--src/node/chainstate.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/src/node/chainstate.h b/src/node/chainstate.h
index 3c950409d3..735906a540 100644
--- a/src/node/chainstate.h
+++ b/src/node/chainstate.h
@@ -45,10 +45,10 @@ enum class ChainstateLoadingError {
* differentiable by the specific enumerator.
*
* Note that a return value of SHUTDOWN_PROBED means ONLY that "during
* this sequence, when we explicitly checked ShutdownRequested() at
* arbitrary points, one of those calls returned true". Therefore, a
* return value other than SHUTDOWN_PROBED does not guarantee that
* ShutdownRequested() hasn't been called indirectly.
* - else
* - Success!
*/
@@ -61,6 +61,7 @@ std::optional<ChainstateLoadingError> LoadChainstate(bool fReset,
int64_t nBlockTreeDBCache,
int64_t nCoinDBCache,
int64_t nCoinCacheUsage,
+ std::function<bool()> shutdown_requested = nullptr,
std::function<void()> coins_error_cb = nullptr);
enum class ChainstateLoadVerifyError {
@@ -45,10 +45,10 @@ enum class ChainstateLoadingError {
*
* Note that a return value of SHUTDOWN_PROBED means ONLY that "during
- * this sequence, when we explicitly checked ShutdownRequested() at
+ * this sequence, when we explicitly checked shutdown_requested() at
* arbitrary points, one of those calls returned true". Therefore, a
* return value other than SHUTDOWN_PROBED does not guarantee that
@@ -45,10 +45,10 @@ enum class ChainstateLoadingError {
* arbitrary points, one of those calls returned true". Therefore, a
* return value other than SHUTDOWN_PROBED does not guarantee that
- * ShutdownRequested() hasn't been called indirectly.
+ * shutdown_requested() hasn't been called indirectly.
* - else
* - Success!